AnimationBlendTree class

Complete blend tree with parameters and root node

Constructors

AnimationBlendTree({required String id, required String name, required BlendTreeNode rootNode, Map<String, BlendTreeParameter> parameters = const {}, Map<String, dynamic> defaultValues = const {}})
const
AnimationBlendTree.fromMap(Map map)
factory

Properties

defaultValues Map<String, dynamic>
Default parameter values
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this blend tree
final
name String
Display name for this blend tree
final
parameters Map<String, BlendTreeParameter>
Parameter definitions for this blend tree
final
rootNode BlendTreeNode
Root node of the blend tree
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate(Map<String, dynamic> parameterValues) AnimationBlendSet
Evaluate the blend tree with the given parameters
getUsedAnimations() List<String>
Get all animation IDs used in this blend tree
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
validate() bool
Validate the blend tree for consistency

Operators

operator ==(Object other) bool
The equality operator.
inherited