BlendTreeNode class abstract

Represents a node in a blend tree

Implementers

Constructors

BlendTreeNode({required String id, required String name, Map<String, double> position = const {}})
const
BlendTreeNode.fromMap(Map map)
Create from map representation
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this node
final
name String
Display name for this node
final
position Map<String, double>
Position in the blend tree (for editor visualization)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate(Map<String, dynamic> parameters) AnimationBlendSet
Calculate the output of this blend tree node
getUsedAnimations() List<String>
Get all animation IDs used by this node and its children
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Convert to map representation
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited