StateMachineStatus class

Represents the current status of a running state machine

Constructors

StateMachineStatus({required String stateMachineId, required String currentStateId, String? previousStateId, required double timeInState, TransitionStatus? currentTransition, Map<String, dynamic> parameters = const {}, required bool isActive, bool isPaused = false})
const
StateMachineStatus.fromMap(Map map)
factory

Properties

currentStateId String
Current state ID
final
currentTransition TransitionStatus?
Current transition being executed (null if not transitioning)
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool
Whether the state machine is currently active
final
isPaused bool
Whether the state machine is paused
final
isTransitioning bool
Whether the state machine is currently transitioning between states
no setter
parameters Map<String, dynamic>
Current parameters
final
previousStateId String?
Previous state ID (null if this is the first state)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateMachineId String
State machine ID
final
timeInState double
Time spent in current state (seconds)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited