AnimationTransition class
Represents a transition between two animations or blend sets
- Implementers
Constructors
-
AnimationTransition({required String id, String? fromAnimationId, required String toAnimationId, required double duration, TransitionCurve curve = TransitionCurve.linear, bool fadeOut = true, bool fadeIn = true, AnimationBlendMode blendMode = AnimationBlendMode.weighted, int priority = 0, Map<
String, dynamic> ? conditions, bool interruptible = true, double minDuration = 0.0}) -
const
- AnimationTransition.fromMap(Map map)
-
factory
Properties
- blendMode → AnimationBlendMode
-
Blend mode during transition
final
-
conditions
→ Map<
String, dynamic> ? -
Conditions that must be met for this transition to occur
final
- curve → TransitionCurve
-
Curve type for the transition
final
- duration → double
-
Duration of the transition in seconds
final
- fadeIn → bool
-
Whether the target animation should fade in
final
- fadeOut → bool
-
Whether the source animation should fade out
final
- fromAnimationId → String?
-
Source animation ID (null for from-any transition)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this transition
final
- interruptible → bool
-
Whether this transition can be interrupted by other transitions
final
- minDuration → double
-
Minimum time before this transition can be interrupted
final
- priority → int
-
Priority of this transition (higher values override lower ones)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toAnimationId → String
-
Target animation ID
final
Methods
-
canTransitionFrom(
String? currentAnimationId) → bool - Check if this transition can be applied from the given animation
-
checkConditions(
Map< String, dynamic> parameters) → bool - Check if the conditions for this transition are met
-
copyWith(
{String? id, String? fromAnimationId, String? toAnimationId, double? duration, TransitionCurve? curve, bool? fadeOut, bool? fadeIn, AnimationBlendMode? blendMode, int? priority, Map< String, dynamic> ? conditions, bool? interruptible, double? minDuration}) → AnimationTransition -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited