BlendTreeParameter class
Parameter definition for blend trees
Constructors
- BlendTreeParameter({required String name, required BlendTreeParameterType type, required dynamic defaultValue, double? minValue, double? maxValue, String? description})
-
const
- BlendTreeParameter.fromMap(Map map)
-
factory
Properties
- defaultValue → dynamic
-
Default value
final
- description → String?
-
Description of this parameter
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxValue → double?
-
Maximum value (for numeric types)
final
- minValue → double?
-
Minimum value (for numeric types)
final
- name → String
-
Parameter name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → BlendTreeParameterType
-
Parameter type
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited