MultiUserSharedObject class
Multi-user shared object
Constructors
-
const
-
factory
Properties
- createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- isLocked → bool
-
final
- isVisible → bool
-
final
- lastModified → DateTime
-
final
-
metadata
→ Map<
String, dynamic> -
final
- nodeId → String
-
final
- ownerId → String
-
final
- position → Vector3
-
final
- rotation → Quaternion
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → Vector3
-
final
Methods
-
isOwnedBy(
String userId) → bool - Check if object is owned by current user
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override