OcclusionStatus class
Occlusion status for real-time updates
Constructors
- OcclusionStatus({required String occlusionId, required String status, required double progress, String? errorMessage, required DateTime timestamp})
-
const
-
OcclusionStatus.fromMap(Map<
String, dynamic> map) -
Creates an OcclusionStatus from a map
factory
Properties
- errorMessage → String?
-
Error message if any
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isComplete → bool
-
Whether the occlusion processing is complete
no setter
- isFailed → bool
-
Whether the occlusion processing failed
no setter
- isSuccessful → bool
-
Whether the occlusion processing was successful
no setter
- occlusionId → String
-
ID of the occlusion this status refers to
final
- progress → double
-
Progress of occlusion processing (0.0 to 1.0)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
Current status of the occlusion
final
- timestamp → DateTime
-
Timestamp of this status update
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts the OcclusionStatus to a map
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override